# Contributing to ΩQTT

## How to Contribute Issues and Patches

Please submit issues and pull requests via [GitHub](https://github.com/ohmqtt/ohmqtt_python).

## Accepted Contributions

The feedbacks I am most interested in are:
* Security issues.
* Compatibility issues with operating systems, supported Python interpreters, and MQTT brokers.
* Wanted features of MQTT 5.0 which are missing or underrepresented.
* Potential for increasing quality, static analysis and/or testing.

Other feedbacks will be considered.
Please open an issue for discussion before contributing new features.

## Quality Standards

Running the tests is described in [README.md](https://github.com/ohmqtt/ohmqtt_python/blob/main/README.md).
All contributions must pass static analysis and testing.
Test coverage must add up to 100% across operating systems and Python versions in CI.

## Conduct Standards

See the [Code of Conduct](https://github.com/ohmqtt/ohmqtt_python/blob/main/.github/CODE_OF_CONDUCT.md) for required conduct standards.
